Publishing posters
==================

Posters are documents that can be manually supplied in a
time-based manner.

Poster files can be uploaded for a defined time period,
and AlekSIS will then deliver the currently valid version
under a stable menu item and URL.

Posters are organised in psoter groups, which can be
created by administrators. Users can then upload PDF files
which shall be published for each time period.

Users who have the permission to upload posters for at
least one poster group can manager their psoters from the
main menu under the `Documents → Manage posters` menu item.

.. image:: ../_static/manage_posters_list.png
  :width: 600
  :alt: Manage posters

Using the `Upload poster` button or the `Edit` action for
an already uploaded poster will open the dialog for manaing
a document for one time period.

.. image:: ../_static/upload_poster.png
  :width: 600
  :alt: Upload poster

After uploading, AlekSIS will deliver the uploaded file
during the week selected in the form.
